==> lclint_2.1b-1.tar.gz: lclint-2.1b/src/Headers/enumNameSList.h <==
/*
** Copyright (c) Massachusetts Institute of Technology 1994, 1995, 1996.
**          All Rights Reserved.
**          Unpublished rights reserved under the copyright laws of
**          the United States.
**
** THIS MATERIAL IS PROVIDED AS IS, WITH ABSOLUTELY NO WARRANTY EXPRESSED
** OR IMPLIED.  ANY USE IS AT YOUR OWN RISK.
**
** This code is distributed freely and may be used freely under the 
** following conditions:
**
**     1. This notice may not be removed or altered.
**
**     2. This code may not be re-distributed or modified
**        without permission from MIT (contact 
**        lclint-request@larch.lcs.mit.edu.)  
**
**        Modification and re-distribution are encouraged,
**        but we want to keep track of changes and
**        distribution sites.
*/
# ifndef enumNameSLIST_H
# define enumNameSLIST_H

abst_typedef enumNameList enumNameSList;

extern int enumNameSList_size (enumNameSList) /*@*/ ;
# define enumNameSList_size(s) enumNameList_size(s)

extern /*@only@*/ enumNameSList enumNameSList_subtract (enumNameList, enumNameSList);
# define enumNameSList_subtract(s,t) enumNameList_subtract(s,t)

extern /*@only@*/ enumNameSList enumNameSList_new(void);
# define enumNameSList_new() enumNameList_new()

extern bool enumNameSList_member (enumNameSList s, cstring m);
# define enumNameSList_member(s,m) enumNameList_member(s,m)

extern void enumNameSList_addh (enumNameSList s, /*@dependent@*/ enumName el) ;
/*@-dependenttrans@*/
# define enumNameSList_addh(s,el) enumNameList_addh(s, el)
/*@=dependenttrans@*/

extern void enumNameSList_free (/*@only@*/ enumNameSList s);

extern /*@only@*/ cstring enumNameSList_unparse (enumNameSList s) /*@*/ ;
# define enumNameSList_unparse(s) enumNameList_unparse(s)

# else
# error "Multiple include"
# endif

==> lclint_2.4b.orig.tar.gz: lclint-2.4b/src/Headers/enumNameSList.h <==
/*
** Copyright (c) Massachusetts Institute of Technology 1994-1998.
**          All Rights Reserved.
**          Unpublished rights reserved under the copyright laws of
**          the United States.
**
** THIS MATERIAL IS PROVIDED AS IS, WITH ABSOLUTELY NO WARRANTY EXPRESSED
** OR IMPLIED.  ANY USE IS AT YOUR OWN RISK.
**
** This code is distributed freely and may be used freely under the 
** following conditions:
**
**     1. This notice may not be removed or altered.
**
**     2. Works derived from this code are not distributed for
**        commercial gain without explicit permission from MIT 
**        (for permission contact lclint-request@sds.lcs.mit.edu).
*/
# ifndef enumNameSLIST_H
# define enumNameSLIST_H

abst_typedef enumNameList enumNameSList;

extern int enumNameSList_size (enumNameSList) /*@*/ ;
# define enumNameSList_size(s) enumNameList_size(s)

extern /*@only@*/ enumNameSList enumNameSList_subtract (enumNameList, enumNameSList);
# define enumNameSList_subtract(s,t) enumNameList_subtract(s,t)

extern /*@only@*/ enumNameSList enumNameSList_new(void);
# define enumNameSList_new() enumNameList_new()

extern bool enumNameSList_member (enumNameSList p_s, cstring p_m);
# define enumNameSList_member(s,m) enumNameList_member(s,m)

extern void enumNameSList_addh (enumNameSList p_s, /*@dependent@*/ enumName p_el) ;
/*@-dependenttrans@*/
# define enumNameSList_addh(s,el) enumNameList_addh(s, el)
/*@=dependenttrans@*/

extern void enumNameSList_free (/*@only@*/ enumNameSList p_s);

extern /*@only@*/ cstring enumNameSList_unparse (enumNameSList p_s) /*@*/ ;
# define enumNameSList_unparse(s) enumNameList_unparse(s)

# else
# error "Multiple include"
# endif
